# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PluginSpoofingTypePluginIListMultiLevelChoice(Model):
    """PluginSpoofingTypePluginIListMultiLevelChoice.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Possible values include: 'enabled', 'disabled'
    :type value: str or ~kameleo.local_api_client.models.enum
    :param extra:
    :type extra: list[str]
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'extra': {'key': 'extra', 'type': '[str]'},
    }

    def __init__(self, *, value, extra=None, **kwargs) -> None:
        super(PluginSpoofingTypePluginIListMultiLevelChoice, self).__init__(**kwargs)
        self.value = value
        self.extra = extra



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfilePreview(Model):
    """A preview about the profile with some of its properties.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. A unique identifier of the profile
    :type id: str
    :param last_known_path: An absolute path where the related .kameleo
     profile file was accessed lastly. This is updated when a profile is saved
     to a .kameleo file, or loaded from a .kameleo file.
    :type last_known_path: str
    :param device: Required.
    :type device: ~kameleo.local_api_client.models.Device
    :param os: Required.
    :type os: ~kameleo.local_api_client.models.Os
    :param browser: Required.
    :type browser: ~kameleo.local_api_client.models.Browser
    :param language: Required. Language of the profile. This is derived from
     the base profile. Using ISO 639-1 language codes.
    :type language: str
    :param launcher: Required. The mode how the profile should be launched. It
     determines which browser to launch. This cannot be modified after
     creation. Possible values are 'automatic', 'chrome', 'chromium',
     'firefox', 'edge', 'external'
    :type launcher: str
    :param status: Required.
    :type status: ~kameleo.local_api_client.models.StatusResponse
    """

    _validation = {
        'id': {'required': True},
        'device': {'required': True},
        'os': {'required': True},
        'browser': {'required': True},
        'language': {'required': True},
        'launcher': {'required': True},
        'status': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'last_known_path': {'key': 'lastKnownPath', 'type': 'str'},
        'device': {'key': 'device', 'type': 'Device'},
        'os': {'key': 'os', 'type': 'Os'},
        'browser': {'key': 'browser', 'type': 'Browser'},
        'language': {'key': 'language', 'type': 'str'},
        'launcher': {'key': 'launcher', 'type': 'str'},
        'status': {'key': 'status', 'type': 'StatusResponse'},
    }

    def __init__(self, **kwargs):
        super(ProfilePreview, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.last_known_path = kwargs.get('last_known_path', None)
        self.device = kwargs.get('device', None)
        self.os = kwargs.get('os', None)
        self.browser = kwargs.get('browser', None)
        self.language = kwargs.get('language', None)
        self.launcher = kwargs.get('launcher', None)
        self.status = kwargs.get('status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model
from msrest.exceptions import HttpOperationError


class TestProxyResponse(Model):
    """TestProxyResponse.

    All required parameters must be populated in order to send to Azure.

    :param is_valid_proxy: Required. Tells weather the proxy is valid or not.
    :type is_valid_proxy: bool
    :param message: Required. A written message about the result of the test.
    :type message: str
    """

    _validation = {
        'is_valid_proxy': {'required': True},
        'message': {'required': True},
    }

    _attribute_map = {
        'is_valid_proxy': {'key': 'isValidProxy', 'type': 'bool'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TestProxyResponse, self).__init__(**kwargs)
        self.is_valid_proxy = kwargs.get('is_valid_proxy', None)
        self.message = kwargs.get('message', None)


class TestProxyResponseException(HttpOperationError):
    """Server responsed with exception of type: 'TestProxyResponse'.

    :param deserialize: A deserializer
    :param response: Server response to be deserialized.
    """

    def __init__(self, deserialize, response, *args):

        super(TestProxyResponseException, self).__init__(deserialize, response, 'TestProxyResponse', *args)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebDriverSettings(Model):
    """Additional arguments, options and preferences that can be passed to the
    started WebDriver and browser.

    :param arguments: Command line switches that can be passed to the browser
     at startup. It is applicable for both chromium based browsers and for
     firefox.
    :type arguments: list[str]
    :param preferences: List of preferences for browsers that can be passed at
     startup. In case of Chromium based options it will be a user profile
     preference. In case of Firefox profiles it will be a preference.
    :type preferences: list[~kameleo.local_api_client.models.Preference]
    :param additional_options: List of additional WebDriver options that can
     be passed at startup. It is applicable for both chromium based browsers
     and for firefox.
    :type additional_options:
     list[~kameleo.local_api_client.models.Preference]
    """

    _attribute_map = {
        'arguments': {'key': 'arguments', 'type': '[str]'},
        'preferences': {'key': 'preferences', 'type': '[Preference]'},
        'additional_options': {'key': 'additionalOptions', 'type': '[Preference]'},
    }

    def __init__(self, **kwargs):
        super(WebDriverSettings, self).__init__(**kwargs)
        self.arguments = kwargs.get('arguments', None)
        self.preferences = kwargs.get('preferences', None)
        self.additional_options = kwargs.get('additional_options', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.service_client import SDKClient
from msrest import Configuration, Serializer, Deserializer
from .version import VERSION
from msrest.pipeline import ClientRawResponse
from . import models


class KameleoLocalApiClientConfiguration(Configuration):
    """Configuration for KameleoLocalApiClient
    Note that all parameters used to create this instance are saved as instance
    attributes.

    :param str base_url: Service URL
    """

    def __init__(
            self, base_url=None):

        if not base_url:
            base_url = 'http://localhost:5050'

        super(KameleoLocalApiClientConfiguration, self).__init__(base_url)

        self.add_user_agent('kameleo.local_api_client/{}'.format(VERSION))


class KameleoLocalApiClient(SDKClient):
    """You can use the following API endpoints to communicate with the local running Kameleo programmatically.

    :ivar config: Configuration for client.
    :vartype config: KameleoLocalApiClientConfiguration

    :param str base_url: Service URL
    """

    def __init__(
            self, base_url=None):

        self.config = KameleoLocalApiClientConfiguration(base_url)
        super(KameleoLocalApiClient, self).__init__(None, self.config)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self.api_version = 'v1'
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)


    def get_base_profile_search_parameters(
            self, device_type=None, os_family=None, browser_product=None, language=None, custom_headers=None, raw=False, **operation_config):
        """Get the possible values for base profile filtering. We can filter the
        available values. With this we can see for example that what languages
        of profiles do we have for Windows profiles with Chrome.

        :param device_type: Filter option for the Device Type. Possible values
         are 'desktop', 'mobile'. For example set it to mobile if you only want
         to see what os families we have for mobile profiles.
        :type device_type: str
        :param os_family: Filter option for os family. Possible values are
         'windows', 'macos', 'linux', 'android', 'ios'. For example set it to
         windows if you only want to see what languages we have for windows
         profiles.
        :type os_family: str
        :param browser_product: Filter option for browser product. Possible
         values are 'chrome', 'firefox', 'edge', 'safari'. For example set it
         to safari if you only want to see what os families we have for chrome
         profiles.
        :type browser_product: str
        :param language: Filter option for os language. Use ISO 639-1 language
         code format. For example set it to en-gb if you only want to see what
         browser products we have for English profiles.
        :type language: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: BaseProfileSearchParameters or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.BaseProfileSearchParameters
         or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.get_base_profile_search_parameters.metadata['url']

        # Construct parameters
        query_parameters = {}
        if device_type is not None:
            query_parameters['deviceType'] = self._serialize.query("device_type", device_type, 'str')
        if os_family is not None:
            query_parameters['osFamily'] = self._serialize.query("os_family", os_family, 'str')
        if browser_product is not None:
            query_parameters['browserProduct'] = self._serialize.query("browser_product", browser_product, 'str')
        if language is not None:
            query_parameters['language'] = self._serialize.query("language", language, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('BaseProfileSearchParameters', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_base_profile_search_parameters.metadata = {'url': '/base-profile-search-parameters'}

    def search_base_profiles(
            self, device_type=None, os_family=None, browser_product=None, language=None, custom_headers=None, raw=False, **operation_config):
        """Filtering base profiles with some criteria. It will return X base
        profiles. It is not an idempotent method. This means if you are calling
        it twice after each other it may return a different set of base
        profiles.

        :param device_type: Filter option for the Device Type. Possible values
         are 'desktop', 'mobile'. For example set it to mobile if you only want
         to get mobile profiles.
        :type device_type: str
        :param os_family: Filter option for os family. Possible values are
         'windows', 'macos', 'linux', 'android', 'ios'. For example set it to
         windows if you only want to get Windows profiles.
        :type os_family: str
        :param browser_product: Filter option for browser product. Possible
         values are 'chrome', 'firefox', 'edge', 'safari'. For example set it
         to safari if you only want to get profiles with Safari browser.
        :type browser_product: str
        :param language: Filter option for os language. Use ISO 639-1 language
         code format. For example set it to en-gb if you only want to get
         English profiles.
        :type language: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: list or ClientRawResponse if raw=true
        :rtype: list[~kameleo.local_api_client.models.BaseProfilePreview] or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.search_base_profiles.metadata['url']

        # Construct parameters
        query_parameters = {}
        if device_type is not None:
            query_parameters['deviceType'] = self._serialize.query("device_type", device_type, 'str')
        if os_family is not None:
            query_parameters['osFamily'] = self._serialize.query("os_family", os_family, 'str')
        if browser_product is not None:
            query_parameters['browserProduct'] = self._serialize.query("browser_product", browser_product, 'str')
        if language is not None:
            query_parameters['language'] = self._serialize.query("language", language, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[BaseProfilePreview]', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    search_base_profiles.metadata = {'url': '/base-profiles'}

    def list_cookies(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Gets the list of the cookies of the profile.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: list or ClientRawResponse if raw=true
        :rtype: list[~kameleo.local_api_client.models.BrowserCookie] or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.list_cookies.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[BrowserCookie]', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    list_cookies.metadata = {'url': '/profiles/{guid}/cookies'}

    def add_cookies(
            self, guid, body=None, custom_headers=None, raw=False, **operation_config):
        """Adds a list of cookies to the profile. If cookies are already present
        for a domain, they will be overwritten.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param body:
        :type body: list[~kameleo.local_api_client.models.CookieRequest]
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: list or ClientRawResponse if raw=true
        :rtype: list[~kameleo.local_api_client.models.BrowserCookie] or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.add_cookies.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, '[CookieRequest]')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[BrowserCookie]', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    add_cookies.metadata = {'url': '/profiles/{guid}/cookies'}

    def delete_cookies(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Deletes the cookies of the profile.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: None or ClientRawResponse if raw=true
        :rtype: None or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.delete_cookies.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        if raw:
            client_raw_response = ClientRawResponse(None, response)
            return client_raw_response
    delete_cookies.metadata = {'url': '/profiles/{guid}/cookies'}

    def healthcheck(
            self, custom_headers=None, raw=False, **operation_config):
        """Health check request to test if Kameleo has been started and accepting
        connections.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: None or ClientRawResponse if raw=true
        :rtype: None or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.healthcheck.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        if raw:
            client_raw_response = ClientRawResponse(None, response)
            return client_raw_response
    healthcheck.metadata = {'url': '/general/healthcheck'}

    def get_user_info(
            self, custom_headers=None, raw=False, **operation_config):
        """Provides information about the user.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: UserInfoResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.UserInfoResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.get_user_info.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('UserInfoResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_user_info.metadata = {'url': '/general/user-info'}

    def terminate_application(
            self, custom_headers=None, raw=False, **operation_config):
        """Terminates the Kameleo session by deauthenticating and exiting the CLI.
        It is important to call it after operating with Kameleo, so other users
        of the team account won't be logged out.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: None or ClientRawResponse if raw=true
        :rtype: None or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.terminate_application.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        if raw:
            client_raw_response = ClientRawResponse(None, response)
            return client_raw_response
    terminate_application.metadata = {'url': '/general/terminate'}

    def test_proxy(
            self, body=None, custom_headers=None, raw=False, **operation_config):
        """Tests a provided proxy connection.

        :param body:
        :type body: ~kameleo.local_api_client.models.TestProxyRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: TestProxyResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.TestProxyResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`TestProxyResponseException<kameleo.local_api_client.models.TestProxyResponseException>`
        """
        # Construct URL
        url = self.test_proxy.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'TestProxyRequest')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.TestProxyResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('TestProxyResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    test_proxy.metadata = {'url': '/general/test-proxy'}

    def list_profiles(
            self, custom_headers=None, raw=False, **operation_config):
        """Gets a preview list about profiles that are currently in the system.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: list or ClientRawResponse if raw=true
        :rtype: list[~kameleo.local_api_client.models.ProfilePreview] or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.list_profiles.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[ProfilePreview]', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    list_profiles.metadata = {'url': '/profiles'}

    def create_profile(
            self, body=None, custom_headers=None, raw=False, **operation_config):
        """Creates a new profile based on a selected BaseProfile and inputs.

        :param body:
        :type body: ~kameleo.local_api_client.models.CreateProfileRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: ProfileResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.ProfileResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.create_profile.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'CreateProfileRequest')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('ProfileResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    create_profile.metadata = {'url': '/profiles/new'}

    def update_profile(
            self, guid, body=None, custom_headers=None, raw=False, **operation_config):
        """Updates profile settings.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param body:
        :type body: ~kameleo.local_api_client.models.UpdateProfileRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: ProfileResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.ProfileResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.update_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'UpdateProfileRequest')
        else:
            body_content = None

        # Construct and send request
        request = self._client.put(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('ProfileResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    update_profile.metadata = {'url': '/profiles/{guid}'}

    def read_profile(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Returns a profile from the system.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: ProfileResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.ProfileResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.read_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('ProfileResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    read_profile.metadata = {'url': '/profiles/{guid}'}

    def delete_profile(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Removes profile from the system. When you are launching and stopping a
        big number of profiles for example for scraping it is recommended to
        call this after you have stopped the profile. This will free up disk
        space.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: None or ClientRawResponse if raw=true
        :rtype: None or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.delete_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        if raw:
            client_raw_response = ClientRawResponse(None, response)
            return client_raw_response
    delete_profile.metadata = {'url': '/profiles/{guid}'}

    def get_profile_status(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Returns the current status of the profile.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: StatusResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.StatusResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.get_profile_status.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('StatusResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profile_status.metadata = {'url': '/profiles/{guid}/status'}

    def start_profile(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Starts a profile. The browser will be launched. In case of mobile
        profiles and external launcher types the external spoofing engine will
        be launched.
        If successful, the profile's lifetime state will be 'running'.
        Otherwise the profile's lifetime state will be 'terminated'. During the
        api call the lifetime state can be 'starting' for a temporarily.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: StatusResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.StatusResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.start_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('StatusResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    start_profile.metadata = {'url': '/profiles/{guid}/start'}

    def start_profile_with_web_driver_settings(
            self, guid, body=None, custom_headers=None, raw=False, **operation_config):
        """Starts a profile, for desktop profiles additional WebDriver settings
        can be provided. The browser will be launched. In case of mobile
        profiles and external launcher types the external spoofing engine will
        be launched.
        If successful, the profile's lifetime state will be 'running'.
        Otherwise the profile's lifetime state will be 'terminated'. During the
        api call the lifetime state can be 'starting' for a temporarily.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param body:
        :type body: ~kameleo.local_api_client.models.WebDriverSettings
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: StatusResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.StatusResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.start_profile_with_web_driver_settings.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'WebDriverSettings')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('StatusResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    start_profile_with_web_driver_settings.metadata = {'url': '/profiles/{guid}/start'}

    def stop_profile(
            self, guid, custom_headers=None, raw=False, **operation_config):
        """Stops a profile. The browsers will be stopped. In case of mobile
        profiles and external launcher types the external spoofing engine will
        be stopped.
        If successful, the profile's lifetime state will be 'terminated'.
        Otherwise the profile's lifetime state will be 'running'. During the
        api call the lifetime state can be 'terminating' for a temporarily.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: StatusResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.StatusResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.stop_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('StatusResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    stop_profile.metadata = {'url': '/profiles/{guid}/stop'}

    def save_profile(
            self, guid, body=None, custom_headers=None, raw=False, **operation_config):
        """Saves a profile to a file. It will create a .kameleo file to the
        required location. It will store all the profile settings, browsing
        data, cookies, history, bookmarks, installed extension / addons. Later
        it can be reloaded.

        :param guid: The unique identifier of the profile
        :type guid: str
        :param body:
        :type body: ~kameleo.local_api_client.models.SaveProfileRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: ProfileResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.ProfileResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.save_profile.metadata['url']
        path_format_arguments = {
            'guid': self._serialize.url("guid", guid, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'SaveProfileRequest')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('ProfileResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    save_profile.metadata = {'url': '/profiles/{guid}/save'}

    def load_profile(
            self, body=None, custom_headers=None, raw=False, **operation_config):
        """Loads a profile from a file. It will load the profile from a .kameleo
        file. It will load all the profile settings, browsing data, cookies,
        history, bookmarks, installed extension / addons.

        :param body:
        :type body: ~kameleo.local_api_client.models.LoadProfileRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: ProfileResponse or ClientRawResponse if raw=true
        :rtype: ~kameleo.local_api_client.models.ProfileResponse or
         ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`ProblemResponseException<kameleo.local_api_client.models.ProblemResponseException>`
        """
        # Construct URL
        url = self.load_profile.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        if body is not None:
            body_content = self._serialize.body(body, 'LoadProfileRequest')
        else:
            body_content = None

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200]:
            raise models.ProblemResponseException(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('ProfileResponse', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    load_profile.metadata = {'url': '/profiles/load'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BrowserCookie(Model):
    """Representation of a cookie.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param domain: Required. The domain attribute signifies the domain for
     which the cookie is valid and can be submitted with every request for this
     domain or its subdomains. If this attribute is not specified, then the
     hostname of the originating server is used as the default value.
    :type domain: str
    :param name: Required. The name for the Cookie.
    :type name: str
    :param path: Required. The path attribute indicates a URL path that must
     exist in the requested URL in order to send the Cookie header. The %x2F
     ("/") character is considered a directory separator, and subdirectories
     match as well.
    :type path: str
    :param value: Required. The value of the Cookie.
    :type value: str
    :param host_only: Required. Host Only cookie means that the cookie should
     be handled by the browser to the server only to the same host/server that
     firstly sent it to the browser.
    :type host_only: bool
    :param http_only: Required. When this attribute is set, client-side
     scripts are not allowed to access the cookie.
    :type http_only: bool
    :param secure: Required. A cookie with the Secure attribute is sent to the
     server only with an encrypted request over the HTTPS protocol, never with
     unsecured HTTP, and therefore can't easily be accessed by a
     man-in-the-middle attacker. Insecure sites (with http: in the URL) can't
     set cookies with the Secure attribute.
    :type secure: bool
    :param same_site: Required. The sameSite attribute lets servers require
     that a cookie shouldn't be sent with cross-origin requests (where Site is
     defined by the registrable domain), which provides some protection against
     cross-site request forgery attacks (CSRF).
     It takes three possible values: Strict, Lax, and None.With Strict, the
     cookie is sent only to the same site as the one that originated it; Lax is
     similar, with an exception for when the user navigates to a URL from an
     external site, such as by following a link; None has no restrictions on
     cross-site requests.
    :type same_site: str
    :ivar expiration_date: This unix timestamp formatted attribute is used to
     set persistent cookies. It signifies how long the browser should use the
     persistent cookie and when the cookie should be deleted.
     If this attribute is not specified, then the lifetime of the cookie is the
     same as that of browser session, i.e.it will be a non-persistent cookie.
    :vartype expiration_date: long
    :ivar session: Session cookies are deleted when the current session ends.
     The browser defines when the "current session" ends, and some browsers use
     session restoring when restarting, which can cause session cookies to last
     indefinitely long.
    :vartype session: bool
    :ivar store_id: The ID of the cookie store containing this cookie.
    :vartype store_id: str
    """

    _validation = {
        'domain': {'required': True},
        'name': {'required': True},
        'path': {'required': True},
        'value': {'required': True},
        'host_only': {'required': True},
        'http_only': {'required': True},
        'secure': {'required': True},
        'same_site': {'required': True},
        'expiration_date': {'readonly': True},
        'session': {'readonly': True},
        'store_id': {'readonly': True},
    }

    _attribute_map = {
        'domain': {'key': 'domain', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'path': {'key': 'path', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'host_only': {'key': 'hostOnly', 'type': 'bool'},
        'http_only': {'key': 'httpOnly', 'type': 'bool'},
        'secure': {'key': 'secure', 'type': 'bool'},
        'same_site': {'key': 'sameSite', 'type': 'str'},
        'expiration_date': {'key': 'expirationDate', 'type': 'long'},
        'session': {'key': 'session', 'type': 'bool'},
        'store_id': {'key': 'storeId', 'type': 'str'},
    }

    def __init__(self, *, domain: str, name: str, path: str, value: str, host_only: bool, http_only: bool, secure: bool, same_site: str, **kwargs) -> None:
        super(BrowserCookie, self).__init__(**kwargs)
        self.domain = domain
        self.name = name
        self.path = path
        self.value = value
        self.host_only = host_only
        self.http_only = http_only
        self.secure = secure
        self.same_site = same_site
        self.expiration_date = None
        self.session = None
        self.store_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Os(Model):
    """Os.

    All required parameters must be populated in order to send to Azure.

    :param family: Required. Family of the OS. Possible values are 'windows',
     'macos', 'linux', 'android', 'ios'.
    :type family: str
    :param version: Required. Version of the OS. For example it helps you
     determine the exact version of the macOS.
    :type version: str
    :param platform: Required. Platform of the OS. Tells if it runs on 64 bit
     or 32 bit or some other processor platform.
    :type platform: str
    """

    _validation = {
        'family': {'required': True},
        'version': {'required': True},
        'platform': {'required': True},
    }

    _attribute_map = {
        'family': {'key': 'family', 'type': 'str'},
        'version': {'key': 'version', 'type': 'str'},
        'platform': {'key': 'platform', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(Os, self).__init__(**kwargs)
        self.family = kwargs.get('family', None)
        self.version = kwargs.get('version', None)
        self.platform = kwargs.get('platform', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Browser(Model):
    """Browser.

    All required parameters must be populated in order to send to Azure.

    :param product: Required. Product of the browser. Possible values are
     'chrome', 'firefox', 'edge', 'safari'.
    :type product: str
    :param major: Required. Major version of the browser.
    :type major: int
    :param version: Required. Exact version of the browser.
    :type version: str
    """

    _validation = {
        'product': {'required': True},
        'major': {'required': True},
        'version': {'required': True},
    }

    _attribute_map = {
        'product': {'key': 'product', 'type': 'str'},
        'major': {'key': 'major', 'type': 'int'},
        'version': {'key': 'version', 'type': 'str'},
    }

    def __init__(self, *, product: str, major: int, version: str, **kwargs) -> None:
        super(Browser, self).__init__(**kwargs)
        self.product = product
        self.major = major
        self.version = version



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseProfileSearchParameters(Model):
    """Provides possible values for base profile filtering. For example it tells
    what os languages are available.

    All required parameters must be populated in order to send to Azure.

    :param device_types: Required. List of possible device types. Possible
     values are 'desktop', 'mobile'.
    :type device_types: list[str]
    :param os_families: Required. List of possible os families. Possible
     values are 'windows', 'macos', 'linux', 'android', 'ios'.
    :type os_families: list[str]
    :param browser_products: Required. List of possible browser products.
     Possible values are 'chrome', 'firefox', 'edge', 'safari'.
    :type browser_products: list[str]
    :param languages: Required. List of possible os languages. It using the
     ISO 639-1 language code format.
    :type languages: list[str]
    """

    _validation = {
        'device_types': {'required': True},
        'os_families': {'required': True},
        'browser_products': {'required': True},
        'languages': {'required': True},
    }

    _attribute_map = {
        'device_types': {'key': 'deviceTypes', 'type': '[str]'},
        'os_families': {'key': 'osFamilies', 'type': '[str]'},
        'browser_products': {'key': 'browserProducts', 'type': '[str]'},
        'languages': {'key': 'languages', 'type': '[str]'},
    }

    def __init__(self, *, device_types, os_families, browser_products, languages, **kwargs) -> None:
        super(BaseProfileSearchParameters, self).__init__(**kwargs)
        self.device_types = device_types
        self.os_families = os_families
        self.browser_products = browser_products
        self.languages = languages



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserInfoResponse(Model):
    """UserInfoResponse.

    All required parameters must be populated in order to send to Azure.

    :param user_id: Required. The guid of the user.
    :type user_id: str
    :param email: Required. The email address of the authenticated user.
    :type email: str
    :param subscription_end: Required. The end date of the authenticated
     user's current subscription.
    :type subscription_end: datetime
    :param capabilities: Required. The capabilities that the authenticated
     user owns thanks to his current subscription.
    :type capabilities: list[str]
    :param last_app_login: The last date when the user authenticated by the
     app.
    :type last_app_login: datetime
    """

    _validation = {
        'user_id': {'required': True},
        'email': {'required': True},
        'subscription_end': {'required': True},
        'capabilities': {'required': True},
    }

    _attribute_map = {
        'user_id': {'key': 'userId', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'subscription_end': {'key': 'subscriptionEnd', 'type': 'iso-8601'},
        'capabilities': {'key': 'capabilities', 'type': '[str]'},
        'last_app_login': {'key': 'lastAppLogin', 'type': 'iso-8601'},
    }

    def __init__(self, *, user_id: str, email: str, subscription_end, capabilities, last_app_login=None, **kwargs) -> None:
        super(UserInfoResponse, self).__init__(**kwargs)
        self.user_id = user_id
        self.email = email
        self.subscription_end = subscription_end
        self.capabilities = capabilities
        self.last_app_login = last_app_login



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .device_py3 import Device
    from .os_py3 import Os
    from .browser_py3 import Browser
    from .base_profile_py3 import BaseProfile
    from .base_profile_preview_py3 import BaseProfilePreview
    from .base_profile_search_parameters_py3 import BaseProfileSearchParameters
    from .browser_cookie_py3 import BrowserCookie
    from .cookie_request_py3 import CookieRequest
    from .webgl_spoofing_options_py3 import WebglSpoofingOptions
    from .webgl_spoofing_type_webgl_spoofing_options_multi_level_choice_py3 import WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    from .timezone_spoofing_type_timezone_multi_level_choice_py3 import TimezoneSpoofingTypeTimezoneMultiLevelChoice
    from .geolocation_spoofing_options_py3 import GeolocationSpoofingOptions
    from .geolocation_spoofing_type_geolocation_spoofing_options_multi_level_choice_py3 import GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    from .server_py3 import Server
    from .proxy_connection_type_server_multi_level_choice_py3 import ProxyConnectionTypeServerMultiLevelChoice
    from .web_rtc_spoofing_options_py3 import WebRtcSpoofingOptions
    from .web_rtc_spoofing_type_web_rtc_spoofing_options_multi_level_choice_py3 import WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    from .font_spoofing_type_font_ilist_multi_level_choice_py3 import FontSpoofingTypeFontIListMultiLevelChoice
    from .plugin_spoofing_type_plugin_ilist_multi_level_choice_py3 import PluginSpoofingTypePluginIListMultiLevelChoice
    from .screen_spoofing_type_screen_size_multi_level_choice_py3 import ScreenSpoofingTypeScreenSizeMultiLevelChoice
    from .create_profile_request_py3 import CreateProfileRequest
    from .load_profile_request_py3 import LoadProfileRequest
    from .preference_py3 import Preference
    from .problem_response_py3 import ProblemResponse, ProblemResponseException
    from .status_response_py3 import StatusResponse
    from .profile_preview_py3 import ProfilePreview
    from .profile_response_py3 import ProfileResponse
    from .save_profile_request_py3 import SaveProfileRequest
    from .test_proxy_request_py3 import TestProxyRequest
    from .test_proxy_response_py3 import TestProxyResponse, TestProxyResponseException
    from .update_profile_request_py3 import UpdateProfileRequest
    from .user_info_response_py3 import UserInfoResponse
    from .web_driver_settings_py3 import WebDriverSettings
except (SyntaxError, ImportError):
    from .device import Device
    from .os import Os
    from .browser import Browser
    from .base_profile import BaseProfile
    from .base_profile_preview import BaseProfilePreview
    from .base_profile_search_parameters import BaseProfileSearchParameters
    from .browser_cookie import BrowserCookie
    from .cookie_request import CookieRequest
    from .webgl_spoofing_options import WebglSpoofingOptions
    from .webgl_spoofing_type_webgl_spoofing_options_multi_level_choice import WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    from .timezone_spoofing_type_timezone_multi_level_choice import TimezoneSpoofingTypeTimezoneMultiLevelChoice
    from .geolocation_spoofing_options import GeolocationSpoofingOptions
    from .geolocation_spoofing_type_geolocation_spoofing_options_multi_level_choice import GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    from .server import Server
    from .proxy_connection_type_server_multi_level_choice import ProxyConnectionTypeServerMultiLevelChoice
    from .web_rtc_spoofing_options import WebRtcSpoofingOptions
    from .web_rtc_spoofing_type_web_rtc_spoofing_options_multi_level_choice import WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    from .font_spoofing_type_font_ilist_multi_level_choice import FontSpoofingTypeFontIListMultiLevelChoice
    from .plugin_spoofing_type_plugin_ilist_multi_level_choice import PluginSpoofingTypePluginIListMultiLevelChoice
    from .screen_spoofing_type_screen_size_multi_level_choice import ScreenSpoofingTypeScreenSizeMultiLevelChoice
    from .create_profile_request import CreateProfileRequest
    from .load_profile_request import LoadProfileRequest
    from .preference import Preference
    from .problem_response import ProblemResponse, ProblemResponseException
    from .status_response import StatusResponse
    from .profile_preview import ProfilePreview
    from .profile_response import ProfileResponse
    from .save_profile_request import SaveProfileRequest
    from .test_proxy_request import TestProxyRequest
    from .test_proxy_response import TestProxyResponse, TestProxyResponseException
    from .update_profile_request import UpdateProfileRequest
    from .user_info_response import UserInfoResponse
    from .web_driver_settings import WebDriverSettings

__all__ = [
    'Device',
    'Os',
    'Browser',
    'BaseProfile',
    'BaseProfilePreview',
    'BaseProfileSearchParameters',
    'BrowserCookie',
    'CookieRequest',
    'WebglSpoofingOptions',
    'WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice',
    'TimezoneSpoofingTypeTimezoneMultiLevelChoice',
    'GeolocationSpoofingOptions',
    'GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice',
    'Server',
    'ProxyConnectionTypeServerMultiLevelChoice',
    'WebRtcSpoofingOptions',
    'WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice',
    'FontSpoofingTypeFontIListMultiLevelChoice',
    'PluginSpoofingTypePluginIListMultiLevelChoice',
    'ScreenSpoofingTypeScreenSizeMultiLevelChoice',
    'CreateProfileRequest',
    'LoadProfileRequest',
    'Preference',
    'ProblemResponse', 'ProblemResponseException',
    'StatusResponse',
    'ProfilePreview',
    'ProfileResponse',
    'SaveProfileRequest',
    'TestProxyRequest',
    'TestProxyResponse', 'TestProxyResponseException',
    'UpdateProfileRequest',
    'UserInfoResponse',
    'WebDriverSettings',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Device(Model):
    """Device.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    All required parameters must be populated in order to send to Azure.

    :param type: Required. Type of the device. Possible values are: 'desktop',
     'mobile'.
    :type type: str
    :ivar name: Name of the device. This is only available for mobile
     profiles.
    :vartype name: str
    """

    _validation = {
        'type': {'required': True},
        'name': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, *, type: str, **kwargs) -> None:
        super(Device, self).__init__(**kwargs)
        self.type = type
        self.name = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebRtcSpoofingOptions(Model):
    """When the Geolocation spoofing is set to manual these extra settings will be
    used as well.

    All required parameters must be populated in order to send to Azure.

    :param private_ip: Required. The WebRTC local IP address of the machine.
     It can be an obfuscated value as well.
    :type private_ip: str
    :param public_ip: Required. The WebRTC public IP address of the machine.
    :type public_ip: str
    """

    _validation = {
        'private_ip': {'required': True},
        'public_ip': {'required': True},
    }

    _attribute_map = {
        'private_ip': {'key': 'privateIp', 'type': 'str'},
        'public_ip': {'key': 'publicIp', 'type': 'str'},
    }

    def __init__(self, *, private_ip: str, public_ip: str, **kwargs) -> None:
        super(WebRtcSpoofingOptions, self).__init__(**kwargs)
        self.private_ip = private_ip
        self.public_ip = public_ip



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Server(Model):
    """Represents a server connection. It can be used as a proxy server connection
    as well.

    All required parameters must be populated in order to send to Azure.

    :param host: Required. Gets or sets the hostname where the service is
     provided from.
    :type host: str
    :param port: Required. Gets or sets the port where the service is provided
     from.
    :type port: int
    :param id: Gets or sets the identity information provided for the service.
     This could be a custom id or username or anything which identifies a
     resource on the remote service. Use it as a proxy username. This field is
     optional.
    :type id: str
    :param secret: Gets or sets the shared secret between the client and the
     service provider. Use it as a proxy password. This field is optional.
    :type secret: str
    """

    _validation = {
        'host': {'required': True},
        'port': {'required': True},
    }

    _attribute_map = {
        'host': {'key': 'host', 'type': 'str'},
        'port': {'key': 'port', 'type': 'int'},
        'id': {'key': 'id', 'type': 'str'},
        'secret': {'key': 'secret', 'type': 'str'},
    }

    def __init__(self, *, host: str, port: int, id: str=None, secret: str=None, **kwargs) -> None:
        super(Server, self).__init__(**kwargs)
        self.host = host
        self.port = port
        self.id = id
        self.secret = secret



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseProfile(Model):
    """Representation of a base profile which is used to build profiles from.

    All required parameters must be populated in order to send to Azure.

    :param version: Required. The version of the base profile. As time passes
     new base profile versions will be introduced. It is recommended to use the
     latest one.
    :type version: str
    :param id: Required. The unique identifier of the base profile. You can
     use this as a reference to create a new profile from this base profile.
    :type id: str
    :param device: Required.
    :type device: ~kameleo.local_api_client.models.Device
    :param os: Required.
    :type os: ~kameleo.local_api_client.models.Os
    :param browser: Required.
    :type browser: ~kameleo.local_api_client.models.Browser
    :param language: Required. Language of the base profile. Using ISO 639-1
     language codes.
    :type language: str
    :param resolution: Required. The screen size of the device in pixels
    :type resolution: str
    :param fonts: Required. A list of font types included in the profile
    :type fonts: list[str]
    :param plugins: Required. A list of plugins included in the profile
    :type plugins: list[str]
    """

    _validation = {
        'version': {'required': True},
        'id': {'required': True},
        'device': {'required': True},
        'os': {'required': True},
        'browser': {'required': True},
        'language': {'required': True},
        'resolution': {'required': True},
        'fonts': {'required': True},
        'plugins': {'required': True},
    }

    _attribute_map = {
        'version': {'key': 'version', 'type': 'str'},
        'id': {'key': 'id', 'type': 'str'},
        'device': {'key': 'device', 'type': 'Device'},
        'os': {'key': 'os', 'type': 'Os'},
        'browser': {'key': 'browser', 'type': 'Browser'},
        'language': {'key': 'language', 'type': 'str'},
        'resolution': {'key': 'resolution', 'type': 'str'},
        'fonts': {'key': 'fonts', 'type': '[str]'},
        'plugins': {'key': 'plugins', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(BaseProfile, self).__init__(**kwargs)
        self.version = kwargs.get('version', None)
        self.id = kwargs.get('id', None)
        self.device = kwargs.get('device', None)
        self.os = kwargs.get('os', None)
        self.browser = kwargs.get('browser', None)
        self.language = kwargs.get('language', None)
        self.resolution = kwargs.get('resolution', None)
        self.fonts = kwargs.get('fonts', None)
        self.plugins = kwargs.get('plugins', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeolocationSpoofingOptions(Model):
    """When the Geolocation spoofing is set to manual these extra settings will be
    used as well.

    All required parameters must be populated in order to send to Azure.

    :param latitude: Required. From -90 to 90
    :type latitude: float
    :param longitude: Required. From -180 to 180
    :type longitude: float
    """

    _validation = {
        'latitude': {'required': True},
        'longitude': {'required': True},
    }

    _attribute_map = {
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
    }

    def __init__(self, *, latitude: float, longitude: float, **kwargs) -> None:
        super(GeolocationSpoofingOptions, self).__init__(**kwargs)
        self.latitude = latitude
        self.longitude = longitude



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model
from msrest.exceptions import HttpOperationError


class ProblemResponse(Model):
    """ProblemResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar code:
    :vartype code: int
    :param error:
    :type error: dict[str, list[str]]
    """

    _validation = {
        'code': {'readonly': True},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'int'},
        'error': {'key': 'error', 'type': '{[str]}'},
    }

    def __init__(self, *, error=None, **kwargs) -> None:
        super(ProblemResponse, self).__init__(**kwargs)
        self.code = None
        self.error = error


class ProblemResponseException(HttpOperationError):
    """Server responsed with exception of type: 'ProblemResponse'.

    :param deserialize: A deserializer
    :param response: Server response to be deserialized.
    """

    def __init__(self, deserialize, response, *args):

        super(ProblemResponseException, self).__init__(deserialize, response, 'ProblemResponse', *args)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreateProfileRequest(Model):
    """CreateProfileRequest.

    All required parameters must be populated in order to send to Azure.

    :param base_profile_id: Required. The unique identifier of the base
     profile. This references the base profile which should be used to build
     the new profile.
    :type base_profile_id: str
    :param canvas: Required. Possible values include: 'intelligent', 'noise',
     'block', 'off'
    :type canvas: str or ~kameleo.local_api_client.models.enum
    :param webgl: Required.
    :type webgl:
     ~kameleo.local_api_client.models.WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    :param timezone: Required.
    :type timezone:
     ~kameleo.local_api_client.models.TimezoneSpoofingTypeTimezoneMultiLevelChoice
    :param geolocation: Required.
    :type geolocation:
     ~kameleo.local_api_client.models.GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    :param proxy: Required.
    :type proxy:
     ~kameleo.local_api_client.models.ProxyConnectionTypeServerMultiLevelChoice
    :param web_rtc: Required.
    :type web_rtc:
     ~kameleo.local_api_client.models.WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    :param fonts: Required.
    :type fonts:
     ~kameleo.local_api_client.models.FontSpoofingTypeFontIListMultiLevelChoice
    :param plugins: Required.
    :type plugins:
     ~kameleo.local_api_client.models.PluginSpoofingTypePluginIListMultiLevelChoice
    :param screen: Required.
    :type screen:
     ~kameleo.local_api_client.models.ScreenSpoofingTypeScreenSizeMultiLevelChoice
    :param start_page: This website will be opened in the browser when the
     profile launches.
    :type start_page: str
    :param password_manager: Possible values include: 'enabled', 'disabled'
    :type password_manager: str or ~kameleo.local_api_client.models.enum
    :param extensions: A list of abolute paths from where the profile should
     load extensions or addons when starting the browser. For chrome and edge
     use CRX3 format extensions. For firefox use signed xpi format addons.
    :type extensions: list[str]
    :param notes: A free text including any notes written by the user.
    :type notes: str
    :param launcher: The mode how the profile should be launched. It
     determines which browser to launch. This cannot be modified after
     creation. Possible values are 'automatic', 'chrome', 'chromium',
     'firefox', 'edge', 'external'
    :type launcher: str
    """

    _validation = {
        'base_profile_id': {'required': True},
        'canvas': {'required': True},
        'webgl': {'required': True},
        'timezone': {'required': True},
        'geolocation': {'required': True},
        'proxy': {'required': True},
        'web_rtc': {'required': True},
        'fonts': {'required': True},
        'plugins': {'required': True},
        'screen': {'required': True},
    }

    _attribute_map = {
        'base_profile_id': {'key': 'baseProfileId', 'type': 'str'},
        'canvas': {'key': 'canvas', 'type': 'str'},
        'webgl': {'key': 'webgl', 'type': 'WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice'},
        'timezone': {'key': 'timezone', 'type': 'TimezoneSpoofingTypeTimezoneMultiLevelChoice'},
        'geolocation': {'key': 'geolocation', 'type': 'GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice'},
        'proxy': {'key': 'proxy', 'type': 'ProxyConnectionTypeServerMultiLevelChoice'},
        'web_rtc': {'key': 'webRtc', 'type': 'WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice'},
        'fonts': {'key': 'fonts', 'type': 'FontSpoofingTypeFontIListMultiLevelChoice'},
        'plugins': {'key': 'plugins', 'type': 'PluginSpoofingTypePluginIListMultiLevelChoice'},
        'screen': {'key': 'screen', 'type': 'ScreenSpoofingTypeScreenSizeMultiLevelChoice'},
        'start_page': {'key': 'startPage', 'type': 'str'},
        'password_manager': {'key': 'passwordManager', 'type': 'str'},
        'extensions': {'key': 'extensions', 'type': '[str]'},
        'notes': {'key': 'notes', 'type': 'str'},
        'launcher': {'key': 'launcher', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(CreateProfileRequest, self).__init__(**kwargs)
        self.base_profile_id = kwargs.get('base_profile_id', None)
        self.canvas = kwargs.get('canvas', None)
        self.webgl = kwargs.get('webgl', None)
        self.timezone = kwargs.get('timezone', None)
        self.geolocation = kwargs.get('geolocation', None)
        self.proxy = kwargs.get('proxy', None)
        self.web_rtc = kwargs.get('web_rtc', None)
        self.fonts = kwargs.get('fonts', None)
        self.plugins = kwargs.get('plugins', None)
        self.screen = kwargs.get('screen', None)
        self.start_page = kwargs.get('start_page', None)
        self.password_manager = kwargs.get('password_manager', None)
        self.extensions = kwargs.get('extensions', None)
        self.notes = kwargs.get('notes', None)
        self.launcher = kwargs.get('launcher', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Preference(Model):
    """Represents a Key-Value pair where Value can be a string or a boolean or an
    integer.

    All required parameters must be populated in order to send to Azure.

    :param key: Required. Key of the preference
    :type key: str
    :param value: Required. Value of the preference. It can a string or a
     boolean or an integer
    :type value: object
    """

    _validation = {
        'key': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, *, key: str, value, **kwargs) -> None:
        super(Preference, self).__init__(**kwargs)
        self.key = key
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebglSpoofingOptions(Model):
    """When the WebGL spoofing is set to noise these extra settings can be used to
    ovveride the values in the base profile.

    :param vendor: Unmasked vendor
    :type vendor: str
    :param renderer: Unmasked renderer
    :type renderer: str
    """

    _attribute_map = {
        'vendor': {'key': 'vendor', 'type': 'str'},
        'renderer': {'key': 'renderer', 'type': 'str'},
    }

    def __init__(self, *, vendor: str=None, renderer: str=None, **kwargs) -> None:
        super(WebglSpoofingOptions, self).__init__(**kwargs)
        self.vendor = vendor
        self.renderer = renderer



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CookieRequest(Model):
    """CookieRequest.

    All required parameters must be populated in order to send to Azure.

    :param domain: Required. The domain attribute signifies the domain for
     which the cookie is valid and can be submitted with every request for this
     domain or its subdomains. If this attribute is not specified, then the
     hostname of the originating server is used as the default value.
    :type domain: str
    :param name: Required. The name for the Cookie.
    :type name: str
    :param path: Required. The path attribute indicates a URL path that must
     exist in the requested URL in order to send the Cookie header. The %x2F
     ("/") character is considered a directory separator, and subdirectories
     match as well.
    :type path: str
    :param value: Required. The value of the Cookie.
    :type value: str
    :param host_only: Host Only cookie means that the cookie should be handled
     by the browser to the server only to the same host/server that firstly
     sent it to the browser.
    :type host_only: bool
    :param http_only: When this attribute is set, client-side scripts are not
     allowed to access the cookie.
    :type http_only: bool
    :param secure: A cookie with the Secure attribute is sent to the server
     only with an encrypted request over the HTTPS protocol, never with
     unsecured HTTP, and therefore can't easily be accessed by a
     man-in-the-middle attacker. Insecure sites (with http: in the URL) can't
     set cookies with the Secure attribute.
    :type secure: bool
    :param same_site: The sameSite attribute lets servers require that a
     cookie shouldn't be sent with cross-origin requests (where Site is defined
     by the registrable domain), which provides some protection against
     cross-site request forgery attacks (CSRF).
     It takes three possible values: Strict, Lax, and None.With Strict, the
     cookie is sent only to the same site as the one that originated it; Lax is
     similar, with an exception for when the user navigates to a URL from an
     external site, such as by following a link; None has no restrictions on
     cross-site requests.
    :type same_site: str
    :param expiration_date: This attribute is used to set persistent cookies.
     It signifies how long the browser should use the persistent cookie and
     when the cookie should be deleted.
     If this attribute is not specified, then the lifetime of the cookie is the
     same as that of browser session, i.e.it will be a non-persistent cookie.
    :type expiration_date: long
    """

    _validation = {
        'domain': {'required': True},
        'name': {'required': True},
        'path': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'domain': {'key': 'domain', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'path': {'key': 'path', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'host_only': {'key': 'hostOnly', 'type': 'bool'},
        'http_only': {'key': 'httpOnly', 'type': 'bool'},
        'secure': {'key': 'secure', 'type': 'bool'},
        'same_site': {'key': 'sameSite', 'type': 'str'},
        'expiration_date': {'key': 'expirationDate', 'type': 'long'},
    }

    def __init__(self, *, domain: str, name: str, path: str, value: str, host_only: bool=None, http_only: bool=None, secure: bool=None, same_site: str=None, expiration_date: int=None, **kwargs) -> None:
        super(CookieRequest, self).__init__(**kwargs)
        self.domain = domain
        self.name = name
        self.path = path
        self.value = value
        self.host_only = host_only
        self.http_only = http_only
        self.secure = secure
        self.same_site = same_site
        self.expiration_date = expiration_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseProfilePreview(Model):
    """A preview object of a searched base profile. This contains some information
    about the base profile that will help you choose the right one.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique identifier of the base profile. You can
     use this as a reference to create a new profile from this base profile.
    :type id: str
    :param device: Required.
    :type device: ~kameleo.local_api_client.models.Device
    :param os: Required.
    :type os: ~kameleo.local_api_client.models.Os
    :param browser: Required.
    :type browser: ~kameleo.local_api_client.models.Browser
    :param language: Required. Language of the base profile. Using ISO 639-1
     language codes.
    :type language: str
    """

    _validation = {
        'id': {'required': True},
        'device': {'required': True},
        'os': {'required': True},
        'browser': {'required': True},
        'language': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'device': {'key': 'device', 'type': 'Device'},
        'os': {'key': 'os', 'type': 'Os'},
        'browser': {'key': 'browser', 'type': 'Browser'},
        'language': {'key': 'language', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BaseProfilePreview, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.device = kwargs.get('device', None)
        self.os = kwargs.get('os', None)
        self.browser = kwargs.get('browser', None)
        self.language = kwargs.get('language', None)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name='kameleo.local_api_client',
    version='2.3.0',
    author='Kameleo Team',
    author_email='support@kameleo.io',
    description='This Python package provides convenient access to the Local API REST interface of the Kameleo Client.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/kameleo-io/local-api-client-python',
    packages=setuptools.find_packages(),
    install_requires=['msrest'],
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
 )



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StatusResponse(Model):
    """Status information about the profile.

    All required parameters must be populated in order to send to Azure.

    :param persistence_state: Required. Possible values include: 'unsaved',
     'saved'
    :type persistence_state: str or ~kameleo.local_api_client.models.enum
    :param lifetime_state: Required. Possible values include: 'created',
     'starting', 'running', 'terminating', 'terminated'
    :type lifetime_state: str or ~kameleo.local_api_client.models.enum
    :param external_spoofing_engine_port: In case of running profiles which
     use an external browser this shows the connection port (for mobile
     profiles as well).
    :type external_spoofing_engine_port: int
    """

    _validation = {
        'persistence_state': {'required': True},
        'lifetime_state': {'required': True},
    }

    _attribute_map = {
        'persistence_state': {'key': 'persistenceState', 'type': 'str'},
        'lifetime_state': {'key': 'lifetimeState', 'type': 'str'},
        'external_spoofing_engine_port': {'key': 'externalSpoofingEnginePort', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(StatusResponse, self).__init__(**kwargs)
        self.persistence_state = kwargs.get('persistence_state', None)
        self.lifetime_state = kwargs.get('lifetime_state', None)
        self.external_spoofing_engine_port = kwargs.get('external_spoofing_engine_port', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimezoneSpoofingTypeTimezoneMultiLevelChoice(Model):
    """TimezoneSpoofingTypeTimezoneMultiLevelChoice.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Possible values include: 'automatic', 'manual',
     'off'
    :type value: str or ~kameleo.local_api_client.models.enum
    :param extra: When the Timezone spoofing is set to manual the timezone in
     Iana format is required. For example: America/Grenada
    :type extra: str
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'extra': {'key': 'extra', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimezoneSpoofingTypeTimezoneMultiLevelChoice, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.extra = kwargs.get('extra', None)



from .models.create_profile_request_py3 import CreateProfileRequest
from .models.webgl_spoofing_type_webgl_spoofing_options_multi_level_choice_py3 import WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
from .models.timezone_spoofing_type_timezone_multi_level_choice_py3 import TimezoneSpoofingTypeTimezoneMultiLevelChoice
from .models.geolocation_spoofing_type_geolocation_spoofing_options_multi_level_choice_py3 import GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
from .models.proxy_connection_type_server_multi_level_choice_py3 import ProxyConnectionTypeServerMultiLevelChoice
from .models.web_rtc_spoofing_type_web_rtc_spoofing_options_multi_level_choice_py3 import WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
from .models.font_spoofing_type_font_ilist_multi_level_choice_py3 import FontSpoofingTypeFontIListMultiLevelChoice
from .models.plugin_spoofing_type_plugin_ilist_multi_level_choice_py3 import PluginSpoofingTypePluginIListMultiLevelChoice
from .models.screen_spoofing_type_screen_size_multi_level_choice_py3 import ScreenSpoofingTypeScreenSizeMultiLevelChoice


class BuilderForCreateProfile:
    def __init__(self, base_profile_id):
        self.profile_request = self.reset(base_profile_id)

    @staticmethod
    def for_base_profile(base_profile_id):
        return BuilderForCreateProfile(base_profile_id)

    def build(self):
        result = self.profile_request
        self.profile_request = self.reset(result.base_profile_id)
        return result

    def set_canvas(self, value):
        """Tells the mode how the canvas will be spoofed. Possible values:
            'noise': Add some noise to the Canvas generation.
            'block': Completely block the 2D API.
            'off': Turn off the spoofing, use the original settings.
        :param string value: Canvas spoofing type. Possible values: 'noise', 'block', 'off'
        """
        self.profile_request.canvas = value
        return self
    
    def set_webgl(self, value, options):
        """Set the Webgl spoofing. Possible values:
            'noise': Add some noise to the WebGL generation
            'block': Completely block the 3D API
            'off': Turn off the spoofing, use the original settings
        :param string value: WebGL spoofing type. Possible values: 'noise', 'block', 'off'
        :param options: Provide unmasked_vendor and unmasked_renderer
        :type options: ~kameleo.local_api_client.models.WebglSpoofingOptions
        """
        self.profile_request.webgl.value = value
        self.profile_request.webgl.extra = options
        return self

    def set_timezone(self, value, options):
        """Tells the mode how the Timezone will be spoofed. Possble values:
            'automatic': Timezone is automatically set by the IP
            'manual': Timezone is manually overridden in the profile
            'off': Turn off the spoofing, use the original settings
        :param string value: Timezone spoofing type. Possible values: 'automatic', 'manual', 'off'
        :param str options: When the Timezone spoofing is set to manual the timezone in Iana format is required. For example: America/Grenada
        """
        self.profile_request.timezone.value = value
        self.profile_request.timezone.extra = options
        return self

    def set_geolocation(self, value, options):
        """Tells the mode how the Geolocation will be spoofed. Possible values:
            'automatic': Automatically set the values based on the IP address
            'manual': Manually set the longitude and latitude in the profile
            'block': Completely block the GeolocationAPI
            'off': Turn off the spoofing, use the original settings
        :param string value: Geolocation spoofing type. Possible values: 'automatic', 'manual', 'block', 'off'
        :param options: When the Geolocation spoofing is set to manual the Geolocation coordinates must be provided
        :type options: ~kameleo.local_api_client.models.GeolocationSpoofingOptions
        """
        self.profile_request.geolocation.value = value
        self.profile_request.geolocation.extra = options
        return self

    def set_proxy(self, value, options):
        """Proxy connection settings of the profiles. Possible values:
            'none': Direct connection without any proxy.</para>
            'http': Use a HTTP(S) proxy for upstream communication.</para>
            'socks5': Use a SOCKS5 proxy for upstream communication.</para>
            'ssh': Use an SSH connection for upstream communication. Basically a SOCKS5 proxy created at the given SSH host.</para>
        :param string value: Proxy connection type. Possible values: 'none', 'http', 'socks5', 'ssh'
        :param options: When the Proxy connection is set, a Proxy Server must be provided
        :type options: ~kameleo.local_api_client.models.Server
        """
        self.profile_request.proxy.value = value
        self.profile_request.proxy.extra = options
        return self

    def set_web_rtc(self, value, options):
        """Tells the mode how the WebRTC will be spoofed. Possible values:
            'automatic': Automatically set the webRTC public IP by the IP, and generates a random private IP like '2d2f78e7-1b1e-4345-a21b-07c904c98394.local'
            'manual': Manually override the webRTC public IP and private IP in the profile
            'block': Block the WebRTC functionality
            'off': Turn off the spoofing, use the original settings
        :param string value: WebRTC spoofing type. Possible values: 'automatic', 'manual', 'block', 'off'
        :param options: When the WebRTC spoofing is set to manual, the private_ip and public_ip must be provided
        :type options: ~kameleo.local_api_client.models.WebRtcSpoofingOptions
        """
        self.profile_request.web_rtc.value = value
        self.profile_request.web_rtc.extra = options
        return self

    def set_fonts(self, value, options):
        """Tells the mode how the Fonts will be spoofed. Possible values:
            'enabled': Enable fonts spoofing. A list can be provided to override the fonts coming from the base profile.
            'disable': Disable fonts spoofing.
        :param string value: Fonts spoofing type. Possible values: 'enabled', 'disabled'
        :param options: When the Font spoofing is set to enabled, a list can be provided to overrider the fonts coming from the base profile.
        :type options: list[str]
        """
        self.profile_request.fonts.value = value
        self.profile_request.fonts.extra = options
        return self

    def set_plugins(self, value, options):
        """Tells the mode how the Plugins will be spoofed. Possible values:
            'enabled': Enable plugins spoofing. A list can be provided to EXCLUDE plugins from the plugins of the base profile.
            'disable': Disable plugins spoofing.
        :param string value: Plugins spoofing type. Possible values: 'enabled', 'disabled'
        :param options: When the Plugins spoofing is set to enabled, a list can be provided to EXCLUDE plugins from the plugins of the base profile.
        :type options: list[str]
        """
        self.profile_request.plugins.value = value
        self.profile_request.plugins.extra = options
        return self

    def set_start_page(self, value):
        """This website will be opened in the browser when the profile launches.
        :param string value: The url of the start page
        """
        self.profile_request.start_page = value
        return self

    def set_password_manager(self, value):
        """Enable or disable the password manager function in the browser. Possible values:
            'enabled': Enable password manager so browser will ask to save and load passwords on logins.
            'disable': Disable password manager.
        :param string value: Password Manager possible values: 'enabled', 'disabled'
        """
        self.profile_request.password_manager = value
        return self

    def set_screen(self, value, options):
        """Tells the mode how the screen will be spoofed. Possible values:
            'automatic': Automatically override the screen resolution based on the Base Profile.
            'manual': Manually override the screen resolution.
            'off': Turn off the spoofing, use the original settings.
        :param string value: Screen spoofing type. Possible values: 'automatic', 'manual', 'off'
        :param string options: When the Screen spoofing is set to manual, the required screen size must be provided. For example: 1080x1920
        """
        self.profile_request.screen.value = value
        self.profile_request.screen.extra = options
        return self

    def set_extensions(self, absolute_paths):
        """A list of absolute paths from where the profile should load extensions or addons when starting the browser. For chrome and edge use CRX3 format extensions. For firefox use signed xpi format addons.
        :param absolute_paths: A list of abolute paths from where the profile should load extensions or addons when starting the browser.
        :type absolute_paths: list[str]
        """
        self.profile_request.extensions = absolute_paths
        return self
    
    def set_notes(self, notes):
        """A free text including any notes written by the user.
        """
        self.profile_request.notes = notes
        return self

    def set_launcher(self, browser_launcher):
        """The mode how the profile should be launched. It determines which browser to launch. This cannot be modified after creation. Possible values are:
            'automatic': Automatically choose launcher based on DeviceType and BrowserProduct property.
            'chrome': Forcefully start the profile in Chrome.
            'chromium': Forcefully start the profile in Chromium.
            'firefox': Forcefully start the profile in Firefox.
            'edge': Forcefully start the profile in Edge.
            'external': Only start the external spoofing engine and connect any browser manually. This is also used for Mobile Device spoofing.
        :param string browser_launcher: Browser Launcher. Possible values: 'automatic', 'chrome', 'chromium', 'firefox', 'edge', 'external'
        """
        self.profile_request.launcher = browser_launcher
        return self

    def set_recommended_defaults(self):
        """This sets all the profile options to the defaults recommended by Kameleo Team. Please consider providing Proxy settings to your profile.
        """
        self.profile_request.canvas = "noise"
        self.profile_request.webgl.value = "noise"
        self.profile_request.timezone.value = "automatic"
        self.profile_request.geolocation.value = "automatic"
        self.profile_request.web_rtc.value = "automatic"
        self.profile_request.fonts.value = "enabled"
        self.profile_request.plugins.value = "enabled"
        self.profile_request.screen.value = "automatic"
        self.profile_request.launcher = "automatic"

        return self;
    
    def reset(self, base_profile_id):
        return CreateProfileRequest(
            base_profile_id=base_profile_id,
            canvas="off",
            webgl=WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice(value="off", extra=None),
            timezone=TimezoneSpoofingTypeTimezoneMultiLevelChoice(value="off", extra=None),
            geolocation=GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice(value="off", extra=None),
            proxy=ProxyConnectionTypeServerMultiLevelChoice(value="none", extra=None),
            web_rtc=WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice(value="off", extra=None),
            fonts=FontSpoofingTypeFontIListMultiLevelChoice(value="disabled", extra=None),
            plugins=PluginSpoofingTypePluginIListMultiLevelChoice(value="disabled", extra=None),
            screen=ScreenSpoofingTypeScreenSizeMultiLevelChoice(value="off", extra=None),
            password_manager="disabled")



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileResponse(Model):
    """ProfileResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. A unique identifier of the profile
    :type id: str
    :param last_known_path: An absolute path where the related .kameleo
     profile file was accessed lastly. This is updated when a profile is saved
     to a .kameleo file, or loaded from a .kameleo file.
    :type last_known_path: str
    :param created_at: Required. Date when the profile was created.
    :type created_at: datetime
    :param base_profile: Required.
    :type base_profile: ~kameleo.local_api_client.models.BaseProfile
    :param canvas: Required. Possible values include: 'intelligent', 'noise',
     'block', 'off'
    :type canvas: str or ~kameleo.local_api_client.models.enum
    :param webgl: Required.
    :type webgl:
     ~kameleo.local_api_client.models.WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    :param timezone: Required.
    :type timezone:
     ~kameleo.local_api_client.models.TimezoneSpoofingTypeTimezoneMultiLevelChoice
    :param geolocation: Required.
    :type geolocation:
     ~kameleo.local_api_client.models.GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    :param proxy: Required.
    :type proxy:
     ~kameleo.local_api_client.models.ProxyConnectionTypeServerMultiLevelChoice
    :param web_rtc: Required.
    :type web_rtc:
     ~kameleo.local_api_client.models.WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    :param fonts: Required.
    :type fonts:
     ~kameleo.local_api_client.models.FontSpoofingTypeFontIListMultiLevelChoice
    :param plugins: Required.
    :type plugins:
     ~kameleo.local_api_client.models.PluginSpoofingTypePluginIListMultiLevelChoice
    :param screen: Required.
    :type screen:
     ~kameleo.local_api_client.models.ScreenSpoofingTypeScreenSizeMultiLevelChoice
    :param start_page: Required. This website will be opened in the browser
     when the profile launches.
    :type start_page: str
    :param password_manager: Required. Possible values include: 'enabled',
     'disabled'
    :type password_manager: str or ~kameleo.local_api_client.models.enum
    :param extensions: Required. A list of abolute paths from where the
     profile should load extensions or addons when starting the browser. For
     chrome and edge use CRX3 format extensions. For firefox use signed xpi
     format addons.
    :type extensions: list[str]
    :param notes: Required. A free text including any notes written by the
     user.
    :type notes: str
    :param launcher: Required. The mode how the profile should be launched. It
     determines which browser to launch. This cannot be modified after
     creation. Possible values are 'automatic', 'chrome', 'chromium',
     'firefox', 'edge', 'external'
    :type launcher: str
    :param status: Required.
    :type status: ~kameleo.local_api_client.models.StatusResponse
    """

    _validation = {
        'id': {'required': True},
        'created_at': {'required': True},
        'base_profile': {'required': True},
        'canvas': {'required': True},
        'webgl': {'required': True},
        'timezone': {'required': True},
        'geolocation': {'required': True},
        'proxy': {'required': True},
        'web_rtc': {'required': True},
        'fonts': {'required': True},
        'plugins': {'required': True},
        'screen': {'required': True},
        'start_page': {'required': True},
        'password_manager': {'required': True},
        'extensions': {'required': True},
        'notes': {'required': True},
        'launcher': {'required': True},
        'status': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'last_known_path': {'key': 'lastKnownPath', 'type': 'str'},
        'created_at': {'key': 'createdAt', 'type': 'iso-8601'},
        'base_profile': {'key': 'baseProfile', 'type': 'BaseProfile'},
        'canvas': {'key': 'canvas', 'type': 'str'},
        'webgl': {'key': 'webgl', 'type': 'WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice'},
        'timezone': {'key': 'timezone', 'type': 'TimezoneSpoofingTypeTimezoneMultiLevelChoice'},
        'geolocation': {'key': 'geolocation', 'type': 'GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice'},
        'proxy': {'key': 'proxy', 'type': 'ProxyConnectionTypeServerMultiLevelChoice'},
        'web_rtc': {'key': 'webRtc', 'type': 'WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice'},
        'fonts': {'key': 'fonts', 'type': 'FontSpoofingTypeFontIListMultiLevelChoice'},
        'plugins': {'key': 'plugins', 'type': 'PluginSpoofingTypePluginIListMultiLevelChoice'},
        'screen': {'key': 'screen', 'type': 'ScreenSpoofingTypeScreenSizeMultiLevelChoice'},
        'start_page': {'key': 'startPage', 'type': 'str'},
        'password_manager': {'key': 'passwordManager', 'type': 'str'},
        'extensions': {'key': 'extensions', 'type': '[str]'},
        'notes': {'key': 'notes', 'type': 'str'},
        'launcher': {'key': 'launcher', 'type': 'str'},
        'status': {'key': 'status', 'type': 'StatusResponse'},
    }

    def __init__(self, **kwargs):
        super(ProfileResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.last_known_path = kwargs.get('last_known_path', None)
        self.created_at = kwargs.get('created_at', None)
        self.base_profile = kwargs.get('base_profile', None)
        self.canvas = kwargs.get('canvas', None)
        self.webgl = kwargs.get('webgl', None)
        self.timezone = kwargs.get('timezone', None)
        self.geolocation = kwargs.get('geolocation', None)
        self.proxy = kwargs.get('proxy', None)
        self.web_rtc = kwargs.get('web_rtc', None)
        self.fonts = kwargs.get('fonts', None)
        self.plugins = kwargs.get('plugins', None)
        self.screen = kwargs.get('screen', None)
        self.start_page = kwargs.get('start_page', None)
        self.password_manager = kwargs.get('password_manager', None)
        self.extensions = kwargs.get('extensions', None)
        self.notes = kwargs.get('notes', None)
        self.launcher = kwargs.get('launcher', None)
        self.status = kwargs.get('status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TestProxyRequest(Model):
    """TestProxyRequest.

    All required parameters must be populated in order to send to Azure.

    :param proxy: Required.
    :type proxy:
     ~kameleo.local_api_client.models.ProxyConnectionTypeServerMultiLevelChoice
    """

    _validation = {
        'proxy': {'required': True},
    }

    _attribute_map = {
        'proxy': {'key': 'proxy', 'type': 'ProxyConnectionTypeServerMultiLevelChoice'},
    }

    def __init__(self, **kwargs):
        super(TestProxyRequest, self).__init__(**kwargs)
        self.proxy = kwargs.get('proxy', None)
